==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSelectDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "./type";
import { WebDropdownDescriptionModule } from "./WebDropdownDescriptionModule";
import { WebIconDescriptionModule } from "./WebIconDescriptionModule";
import { WebInputDescriptionModule } from "./WebInputDescriptionModule";
import { WebSelectGroupDescriptionModule } from "./WebSelectGroupDescriptionModule";
import { WebSelectHeaderDescriptionModule } from "./WebSelectHeaderDescriptionModule";
import { WebSelectItemDescriptionModule } from "./WebSelectItemDescriptionModule";
import { WebSelectDescriptionMetadata } from "./WebSelectDescriptionMetadata";
/**
 * @hidden
 */
export let WebSelectDescriptionModule = /*@__PURE__*/ (() => {
    class WebSelectDescriptionModule extends Base {
        static register(a) {
            WebDropdownDescriptionModule.register(a);
            WebIconDescriptionModule.register(a);
            WebInputDescriptionModule.register(a);
            WebSelectGroupDescriptionModule.register(a);
            WebSelectHeaderDescriptionModule.register(a);
            WebSelectItemDescriptionModule.register(a);
            WebSelectDescriptionMetadata.d(a);
        }
    }
    WebSelectDescriptionModule.$t = /*@__PURE__*/ markType(WebSelectDescriptionModule, 'WebSelectDescriptionModule');
    return WebSelectDescriptionModule;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebSelectDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "./type";
import { WebBaseComboBoxLikeDescriptionModule } from "./WebBaseComboBoxLikeDescriptionModule";
import { WebIconDescriptionModule } from "./WebIconDescriptionModule";
import { WebInputDescriptionModule } from "./WebInputDescriptionModule";
import { WebSelectGroupDescriptionModule } from "./WebSelectGroupDescriptionModule";
import { WebSelectHeaderDescriptionModule } from "./WebSelectHeaderDescriptionModule";
import { WebSelectItemDescriptionModule } from "./WebSelectItemDescriptionModule";
import { WebSelectItemComponentEventArgsDescriptionMetadata } from "./WebSelectItemComponentEventArgsDescriptionMetadata";
import { WebSelectDescriptionMetadata } from "./WebSelectDescriptionMetadata";
/**
 * @hidden
 */
export let WebSelectDescriptionModule = /*@__PURE__*/ (() => {
    class WebSelectDescriptionModule extends Base {
        static register(a) {
            WebBaseComboBoxLikeDescriptionModule.register(a);
            WebIconDescriptionModule.register(a);
            WebInputDescriptionModule.register(a);
            WebSelectGroupDescriptionModule.register(a);
            WebSelectHeaderDescriptionModule.register(a);
            WebSelectItemDescriptionModule.register(a);
            WebSelectItemComponentEventArgsDescriptionMetadata.d(a);
            WebSelectDescriptionMetadata.d(a);
        }
    }
    WebSelectDescriptionModule.$t = /*@__PURE__*/ markType(WebSelectDescriptionModule, 'WebSelectDescriptionModule');
    return WebSelectDescriptionModule;
})();
